Skip to contents

A function to compute the BLUP

Usage

compute_blup(fit, Xb, Sigma_21, idx)

Arguments

fit

An object returned by plmm()

Xb

Linear predictor

Sigma_21

Covariance matrix between the training and the testing data. Extracted from estimated_Sigma that is generated using all observations

idx

Vector of indices of the penalty parameter lambda at which predictions are required. By default, all indices are returned.

Value

A matrix of the linear predictors + the estimated random effects