Learn R Programming

plmmr (version 4.3.0)

construct_variance: A function to construct the estimated variance matrix from a PLMM fit

Description

A function to construct the estimated variance matrix from a PLMM fit

Usage

construct_variance(fit, K = NULL, eta = NULL)

Value

Sigma_hat, a matrix representing the estimated variance

Arguments

fit

An object returned by plmm()

K

An optional matrix

eta

An optional numeric value between 0 and 1; if fit is not supplied, then this option must be specified.