Learn R Programming

plmmr (version 4.3.0)

create_log: Create the .log file

Description

Create the .log file

Usage

create_log(outfile)

Value

Nothing is returned, instead a text file with the suffix .log is created. If outfile is NULL, the path to the null device is returned.

Arguments

outfile

String specifying the name of the to-be-created file, without extension