Learn R Programming

plmmr (version 4.2.3)

estimate_eta: Estimate eta (to be used in rotating the data) This function is called internally by plmm()

Description

Estimate eta (to be used in rotating the data) This function is called internally by plmm()

Usage

estimate_eta(n, s, U, y, eta_star)

Value

a numeric value with the estimated value of eta, the variance parameter

Arguments

n

The number of observations

s

The singular values of K, the realized relationship matrix

U

The left-singular vectors of the standardized design matrix

y

Continuous outcome vector.