Learn R Programming

plmmr (version 4.3.0)

find_example_data: A function to help with accessing example PLINK files.

Description

A function to help with accessing example PLINK files.

Usage

find_example_data(path, parent = FALSE)

Value

If path = NULL, a character vector of file names is returned. If path is given, then a character string with the full file path.

Arguments

path

Argument (string) specifying a path (filename) for an external data file in extdata/.

parent

If the user wants the name of the parent directory where the example data is located, set parent = TRUE. Defaults to FALSE.

Examples

Run this code
find_example_data(parent = TRUE)

Run the code above in your browser using DataLab