This function is intended to be called after either process_plink() or process_delim() has been called once.
Value
A list with these components:
std_X, the column-standardized design matrix as either (1) a numeric matrix or (2) a filebackedbig.matrixobject.(if PLINK data)
fam, a data frame containing the pedigree information (like a.famfile in PLINK)(if PLINK data)
map, a data frame containing the feature information (like a.bimfile in PLINK)ns: A vector indicating the which columns of X contain nonsingular features (i.e., features with variance != 0).center: A vector of values for centering each column in Xscale: A vector of values for scaling each column in X