Learn R Programming

plmmr (version 4.2.3)

print.summary.cv_plmm: Print method for summary.cv_plmm objects

Description

Print method for summary.cv_plmm objects

Usage

# S3 method for summary.cv_plmm
print(x, digits, ...)

Value

Nothing is returned; instead, a message is printed to the console summarizing the results of the cross-validated model fit.

Arguments

x

An object of class summary.cv_plmm

digits

The number of digits to use in formatting output

...

Not used

Examples

Run this code
admix_design <- create_design(X = admix$X, y = admix$y)
cv_fit <- cv_plmm(design = admix_design)
print(summary(cv_fit))

Run the code above in your browser using DataLab