Skip to contents

A summary function for cv_plmm objects

Usage

# S3 method for class 'cv_plmm'
summary(object, ...)

Arguments

object

A cv_plmm object

...

Not used

Value

The return value is an object with S3 class summary.cv_plmm. The class has its own print method and contains the following list elements:

  • lambda_min: The lambda value at the minimum cross validation error

  • lambda_1se: The maximum lambda value within 1 standard error of the minimum cross validation error

  • penalty: The penalty applied to the fitted model

  • nvars: The number of variables selected at lambda_min

  • cve: The cross validation error at all folds

  • min: The minimum cross validation error

  • fit: The plmm fit used in the cross validation

Examples

admix_design <- create_design(X = admix$X, y = admix$y)
cv_fit <- cv_plmm(design = admix_design)
summary(cv_fit)
#> lasso-penalized model with n=197 and p=101
#> At minimum cross-validation error (lambda=0.4289):
#> -------------------------------------------------
#>   Nonzero coefficients: 0
#>   Cross-validation error (deviance): 3.36
#>   Scale estimate (sigma): 1.832