Learn R Programming

plmmr (version 4.3.0)

untransform_delim: Untransform coefficient values back to the original scale for file-backed data

Description

This function unwinds the initial standardization of the data to obtain coefficient values on their original scale. It is called by plmm_format().

Usage

untransform_delim(std_scale_beta, p, std_X_details, use_names = TRUE)

Value

a matrix of estimated coefficients, untransformed_beta, that is on the scale of the original data.

Arguments

std_scale_beta

The estimated coefficients on the standardized scale

p

The number of columns in the original design matrix

std_X_details

A list with 3 elements describing the standardized design matrix BEFORE rotation; this should have elements scale, center, and ns

use_names

Logical: should names be added? Defaults to TRUE. Set to FALSE inside of cvf() helper, as ns will vary within CV folds.