create_design_filebacked()A helper function to support create_design_filebacked()
align_ids(id_var, add_predictor, og_ids, outfile, quiet)A matrix with the same dimensions as add_predictor
String specifying the variable name of the ID column
External data to include in design matrix. This is the add_predictor arg in create_design_filebacked()
Character vector with the PLINK ids (FID or IID) from the original data (i.e., the data before any subsetting from handling missing phenotypes)
A string with the name of the filepath for the log file
Logical: should console messages be silenced? Defaults to FALSE