# S3 method for plmm
coef(object, lambda, which = seq_along(object$lambda), drop = TRUE, ...)
Value
Either a numeric matrix (if model was fit on data stored in memory)
or a sparse matrix (if model was fit on data stored filebacked). Rownames are
feature names, columns are values of lambda.
Arguments
object
An object of class "plmm."
lambda
A numeric vector of lambda values.
which
Vector of lambda indices for which coefficients to return.