A function to compute the BLUP
compute_blup(fit, Xb, Sigma_21, idx)A matrix of the linear predictors + the estimated random effects
An object returned by plmm()
Linear predictor
Covariance matrix between the training and the testing data. Extracted from estimated_Sigma that is generated using all observations
Vector of indices of the penalty parameter lambda at which predictions are required. By default, all indices are returned.