powered by
.log
Create the .log file
create_log(outfile)
Nothing is returned, instead a text file with the suffix .log is created. If outfile is NULL, the path to the null device is returned.
String specifying the name of the to-be-created file, without extension