plmm()Estimate eta (to be used in rotating the data)
This function is called internally by plmm()
estimate_eta(n, s, U, y, eta_star)a numeric value with the estimated value of eta, the variance parameter
The number of observations
The singular values of K, the realized relationship matrix
The left-singular vectors of the standardized design matrix
Continuous outcome vector.