powered by
A function to help with accessing example PLINK files.
find_example_data(path, parent = FALSE)
If path = NULL, a character vector of file names is returned. If path is given, then a character string with the full file path.
path = NULL
Argument (string) specifying a path (filename) for an external data file in extdata/.
extdata/
If the user wants the name of the parent directory where the example data is located, set parent = TRUE. Defaults to FALSE.
parent = TRUE
find_example_data(parent = TRUE)
Run the code above in your browser using DataLab