This function allows you to evaluate the negative log-likelihood of a linear mixed model under the assumption of a null model in order to estimate the variance parameter, eta.
log_lik(eta, n, s, U, y, rot_y = NULL)the value of the log-likelihood of the PLMM, evaluated with the supplied parameters
The proportion of variance in the outcome that is attributable to causal SNP effects. In other words, signal-to-noise ratio.
The number of observations
The singular values of K, the realized relationship matrix
The left-singular vectors of the standardized design matrix
Continuous outcome vector.
Optional: if y has already been rotated, then this can be supplied.