bigSNPA helper function to label and summarize the contents of a bigSNP
name_and_count_bigsnp(obj, id_var, quiet, outfile)a list with components:
counts: column-wise summary of the minor allele counts in 'genotypes'
obj: a modified bigSNP list with additional components
X: the obj$genotypes as its own FBM
pos: the obj$map$physical.pos vector
a bigSNP object, possibly subset by add_external_phenotype()
String specifying which column of the PLINK .fam file has the unique sample identifiers. Options are "IID" (default) and "FID".
Logical: should messages be printed to the console? Defaults to TRUE
The string with the name of the .log file