Nothing is returned; instead, a plot of the coefficient paths is drawn
at each value of lambda (one 'path' for each coefficient).
Arguments
x
An object of class plmm
alpha
Tuning parameter for the Mnet estimator which controls the relative contributions from the MCP/SCAD penalty and the ridge, or L2 penalty.
alpha = 1 is equivalent to MCP/SCAD penalty, while alpha = 0 would be equivalent to ridge regression. However, alpha = 0 is not supported; alpha may be arbitrarily small, but not exactly 0.
log.l
Logical to indicate the plot should be returned on the natural log scale. Defaults to FALSE.
shade
Logical to indicate whether a local nonconvex region should be shaded. Defaults to TRUE.