powered by
Print method for summary.cv_plmm objects
# S3 method for summary.cv_plmm print(x, digits, ...)
Nothing is returned; instead, a message is printed to the console summarizing the results of the cross-validated model fit.
An object of class summary.cv_plmm
summary.cv_plmm
The number of digits to use in formatting output
Not used
admix_design <- create_design(X = admix$X, y = admix$y) cv_fit <- cv_plmm(design = admix_design) print(summary(cv_fit))
Run the code above in your browser using DataLab