Learn R Programming

plmmr (version 4.2.3)

print.summary.plmm: A function to print the summary of a plmm model

Description

A function to print the summary of a plmm model

Usage

# S3 method for summary.plmm
print(x, ...)

Value

Nothing is returned; instead, a message is printed to the console summarizing the results of the model fit.

Arguments

x

A summary.plmm object

...

Not used

Examples

Run this code
lam <- rev(seq(0.01, 1, length.out=20)) |> round(2) # for sake of example
admix_design <- create_design(X = admix$X, y = admix$y)
fit <- plmm(design = admix_design, lambda = lam)
fit2 <- plmm(design = admix_design, penalty = "SCAD", lambda = lam)
print(summary(fit, idx = 18))
print(summary(fit2, idx = 18))

Run the code above in your browser using DataLab