A helper function to standardize matrices
standardize_in_memory(X, tocenter = TRUE)A list containing the standardized X matrix and associated metadata
A matrix
Should the matrix be centered in addition to scaled? Defaults to TRUE.
This function is adapted from https://github.com/pbreheny/ncvreg/blob/master/R/std.R
NOTE: this function returns a matrix in memory. For standardizing filebacked
data, use standardize_filebacked() -- see src/big_standardize.cpp