powered by
A summary function for cv_plmm objects
# S3 method for cv_plmm summary(object, lambda = "min", ...)
The return value is an object with S3 class summary.cv_plmm. The class has its own print method and contains the following list elements:
summary.cv_plmm
lambda_min: The lambda value at the minimum cross validation error
lambda_min
lambda.1se: The maximum lambda value within 1 standard error of the minimum cross validation error
lambda.1se
penalty: The penalty applied to the fitted model
penalty
nvars: The number of non-zero coefficients at the selected lambda value
nvars
cve: The cross validation error at all folds
cve
min: The minimum cross validation error
min
fit: The plmm fit used in the cross validation
fit
plmm
if return_bias_details = TRUE, two more items are returned:
return_bias_details = TRUE
bias: The mean bias of the cross validation
bias
loss: The loss at each value of lambda
loss
lambda
A cv_plmm object
cv_plmm
The regularization parameter value at which inference should be reported. Can choose a numeric value, 'min', or '1se'. Defaults to 'min.'
Not used
admix_design <- create_design(X = admix$X, y = admix$y) cv_fit <- cv_plmm(design = admix_design) summary(cv_fit)
Run the code above in your browser using DataLab