A summary method for the plmm objects
# S3 method for plmm
summary(object, lambda, idx, eps = 1e-05, ...)The return value is an object with S3 class summary.plmm. The class has its own print method and contains the following list elements:
penalty: The penalty used by plmm (e.g. SCAD, MCP, lasso)
n: Number of instances/observations
std_X_n: the number of observations in the standardized data;
the only time this would differ from 'n' is if data are from PLINK and the external data does not include all the same samples
p: Number of regression coefficients (not including the intercept)
converged: Logical indicator for whether the model converged
lambda: The lambda value at which inference is being reported
lambda_char: A formatted character string indicating the lambda value
nvars: The number of nonzero coefficients (again, not including the intercept) at that value of lambda
nonzero: The column names indicating the nonzero coefficients in the model at the specified value of lambda
An object of class plmm
The regularization parameter value at which inference should be reported.
Alternatively, lambda may be specified by an index; idx=10 means:
report inference for the 10th value of lambda along the regularization path. If both lambda and idx are specified, lambda takes precedence.
If lambda is given, eps is the tolerance for difference between the given lambda value and a lambda value from the object. Defaults to 0.0001 (1e-5)
Not used
admix_design <- create_design(X = admix$X, y = admix$y)
fit <- plmm(design = admix_design)
summary(fit, idx = 97)
Run the code above in your browser using DataLab