This function unwinds the initial standardization of the data to obtain coefficient values on their original scale. It is called by plmm_format().
untransform_delim(
std_scale_beta,
p,
std_X_details,
plink_flag,
use_names = TRUE
)a matrix of estimated coeffcients, 'beta_vals', that is on the scale of the original data.
The estimated coefficients on the standardized scale
The number of columns in the original design matrix
A list with 3 elements describing the standardized design matrix BEFORE rotation; this should have elements 'scale', 'center', and 'ns'
Logical: should names be added? Defaults to TRUE. Set to FALSE inside of cvf() helper, as 'ns' will vary within CV folds.