Learn R Programming

plmmr (version 4.3.0)

unzip_example_data: Companion function to unzip the .gz files that ship with the plmmr package.

Description

Companion function to unzip the .gz files that ship with the plmmr package.

Usage

unzip_example_data(outdir)

Value

Nothing is returned; the PLINK files that ship with the plmmr package are stored in the directory specified by outdir.

Arguments

outdir

The file path to the directory to which the .gz files should be written.

Details

For an example of this function, look at vignette('plink_files', package = "plmmr").